# Data Mining for Business Analytics: Concepts, Techniques, and  Applications in Python

Collection of utility functions used in the book

> _Data Mining for Business Analytics: Concepts, Techniques, and Applications in Python_ (First Edition) 
> Galit Shmueli, Peter C. Bruce, Peter Gedeck, and Nitin R. Patel
> (c) 2019 John Wiley & Sons, Inc. 

Code for the book and the used datasets are available on https://www.dataminingbook.com/book/python-edition.


## Installation
Use `pip` to install the `dmba` package from pypi (https://pypi.org/project/dmba/).
```
pip install dmba
```
Should this not work, for example when you are behind a firewall, download the package from pypi and install from file, e.g.
```
pip install dmba-0.0.14.tar.gz 
```
